@@ -8,6 +8,7 @@ from http.server import HTTPServer
 from logging.config import dictConfig
 
 from defweb.common.constants import CERT_PATH, KEY_PATH, SIGNED_CERT_PATH
+from defweb.common.mapping_handlers import handler_mapping
 from defweb.common.pki import DefWebPKI
 from defweb.proxy import DefWebProxy
 from defweb.reverse_proxy import DefWebReverseProxy
@@ -121,7 +122,9 @@ def main():
         "--rev_proxy", action="store_true", help="start reverse TCP proxy"
     )
     rev_proxy_grp.add_argument(
-        "--rev_proxy_tls", action="store_true", help="add TLS support to the reverse TCP proxy"
+        "--rev_proxy_tls",
+        action="store_true",
+        help="add TLS support to the reverse TCP proxy",
     )
     rev_proxy_grp.add_argument(
         "-ca",
@@ -155,6 +158,12 @@ def main():
         default=None,
         help="comma seperated middlewares to use",
     )
+    rev_proxy_grp.add_argument(
+        "--protocol",
+        metavar="PROXIED_PROTOCOL",
+        default=None,
+        help="provide the protocol of the service we are proxying for",
+    )
 
     args = parser.parse_args()
 
@@ -184,6 +193,9 @@ def main():
         print(__version__)
         exit(0)
 
+    if not os.path.exists("/tmp/defweb"):
+        os.mkdir("/tmp/defweb")
+
     logger.info(f"Defweb version: {__version__}")
 
     if args.port:
@@ -279,6 +291,7 @@ def main():
                     keyfile=use_key_path,
                     certfile=use_cert_path,
                     server_side=True,
+                    ssl_version=ssl.PROTOCOL_TLSv1_2,
                 )
             else:
                 logger.error(f"Certificate creation produced an error: {result}")
@@ -300,12 +313,18 @@ def main():
                 f"Running DefWebReverseProxy: {DefWebReverseProxy.server_version}"
             )
 
+            handler = "default"
+
+            if args.protocol:
+                handler = args.protocol.lower()
+
             rev_proxy_server = DefWebReverseProxy(
                 socketaddress=(host, port),
                 proxied_ip=args.proxied_ip,
                 proxied_port=args.proxied_port,
                 proxied_tls=args.ptls,
-                middlewares=args.middlewares.split(","),
+                middlewares=args.middlewares.lower().split(","),
+                request_handler_class=handler_mapping[handler],
             ).init_proxy()
 
             if args.rev_proxy_tls:
@@ -330,12 +349,13 @@ def main():
                     if result:
                         use_cert_path = SIGNED_CERT_PATH
 
-                if result:
+                if result and rev_proxy_server is not None:
                     rev_proxy_server.socket = ssl.wrap_socket(
                         rev_proxy_server.socket,
                         keyfile=use_key_path,
                         certfile=use_cert_path,
                         server_side=True,
+                        ssl_version=ssl.PROTOCOL_TLSv1_2,
                     )
                 else:
                     logger.error(f"Certificate creation produced an error: {result}")
@@ -415,3 +435,6 @@ def main():
 
 if __name__ == "__main__":
     main()
+
+
+# TODO setup hook to execute code to cleanup old files from tmp/defweb
